package cz.kebrt.unitcheck.junit;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.util.ArrayList;
import java.util.List;

/**
 * Extract test method names from JUnit3 test cases.
 *
 * @author michal
 */
class JUnit3TestMethodExtractor implements TestMethodExtractor {

    private static final String TEST_PREFIX = "test";
    private Class<?> klass;

    /**
     * Constructs an instance.
     * @param klass JUnit3 test class
     */
    public JUnit3TestMethodExtractor(Class<?> klass) {
        this.klass = klass;
    }

    @Override
    public List<String> getTestMethods() {
        List<String> ret = new ArrayList<String>();
        for (Method m : klass.getDeclaredMethods()) {
            if (isPublicTestMethod(m)) {
                ret.add(m.getName());
            }
        }
        return ret;
    }

    private boolean isPublicTestMethod(Method m) {
        return isTestMethod(m) && Modifier.isPublic(m.getModifiers());
    }

    private boolean isTestMethod(Method m) {
        return m.getParameterTypes().length == 0 && m.getName().startsWith(TEST_PREFIX)
                && m.getReturnType().equals(Void.TYPE);
    }

}
