package cz.kebrt.unitcheck.util;

/**
 * Various string utility methods.
 *
 * @author michal
 *
 */
public final class StringUtil {

    private StringUtil() { }

    /**
     * Creates a new string composed of an arbitrary count of a single character. For
     * arguments '=' and 5, it returns "=====".
     *
     * @param c character that will be repeated in the string
     * @param count how many times the character will be repeated
     * @return new string composed of an arbitrary count of a single character
     */
    public static String newString(final char c, final int count) {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < count; ++i) {
            sb.append(c);
        }
        return sb.toString();
    }

    /**
     * Returns class name from a string. '.java' file extension is removed when needed.
     * For argument 'org.nasa.jpf.JPF', it returns 'JPF'.
     *
     * @param fullName full name of a class (may end with the suffix '.java')
     * @return corresponding class name
     */
    public static String getClassName(final String fullName) {
        if (fullName == null) {
            return null;
        }
        String result = fullName.replace(".java", "");
        int index = result.lastIndexOf('.');
        if (index > 0) {
            return result.substring(index + 1);
        }
        return result;
    }

}
